# API Reference

## Solver Factory

::: invert.Solver

## Base Classes

::: invert.solvers.base.BaseSolver

::: invert.solvers.base.InverseOperator

## Solver Metadata

::: invert.solvers.base.SolverMeta
